==> haskell-unicode-collation-0.1.3.6-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-collation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unicode-collation
version:              0.1.3.6
visibility:           public
id:                   unicode-collation-0.1.3.6-34thcLCMlErDGJgekWy4rw
key:                  unicode-collation-0.1.3.6-34thcLCMlErDGJgekWy4rw
license:              BSD-2-Clause
copyright:            2021 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane
homepage:             https://github.com/jgm/unicode-collation
synopsis:             Haskell implementation of the Unicode Collation Algorithm
description:
    This library provides a pure Haskell implementation of
    the Unicode Collation Algorithm described at
    <http://www.unicode.org/reports/tr10/>.  It is not
    as fully-featured or as performant as @text-icu@, but
    it avoids a dependency on a large C library.
    Locale-specific tailorings are also provided.

category:             Text
abi:                  11425e9a2b777856bd0279520ba921fb
exposed:              True
exposed-modules:      Text.Collate Text.Collate.Lang Text.Collate.Normalize
hidden-modules:
    Text.Collate.Trie Text.Collate.Collation Text.Collate.Collator
    Text.Collate.CanonicalCombiningClass Text.Collate.TH
    Text.Collate.Tailorings Text.Collate.UnicodeData

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unicode-collation-0.1.3.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unicode-collation-0.1.3.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unicode-collation-0.1.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-collation
hs-libraries:         HSunicode-collation-0.1.3.6-34thcLCMlErDGJgekWy4rw
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    parsec-3.1.16.1 template-haskell-2.19.0.0 text-2.0.2
    th-lift-instances-0.1.20-IrFuy1F8A85FoBrEkfwl08

haddock-interfaces:
    /usr/share/doc/haskell-unicode-collation/html/unicode-collation.haddock

haddock-html:         /usr/share/doc/haskell-unicode-collation/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-collation-0.1.3.6-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-collation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unicode-collation
version:              0.1.3.6
visibility:           public
id:                   unicode-collation-0.1.3.6-LjGDzBD4fipATjFZGn8GKN
key:                  unicode-collation-0.1.3.6-LjGDzBD4fipATjFZGn8GKN
license:              BSD-2-Clause
copyright:            2021 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane
homepage:             https://github.com/jgm/unicode-collation
synopsis:             Haskell implementation of the Unicode Collation Algorithm
description:
    This library provides a pure Haskell implementation of
    the Unicode Collation Algorithm described at
    <http://www.unicode.org/reports/tr10/>.  It is not
    as fully-featured or as performant as @text-icu@, but
    it avoids a dependency on a large C library.
    Locale-specific tailorings are also provided.

category:             Text
abi:                  a67f59a917e9afb8413bbb49d576de8a
exposed:              True
exposed-modules:      Text.Collate Text.Collate.Lang Text.Collate.Normalize
hidden-modules:
    Text.Collate.Trie Text.Collate.Collation Text.Collate.Collator
    Text.Collate.CanonicalCombiningClass Text.Collate.TH
    Text.Collate.Tailorings Text.Collate.UnicodeData

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unicode-collation-0.1.3.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unicode-collation-0.1.3.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unicode-collation-0.1.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-collation
hs-libraries:         HSunicode-collation-0.1.3.6-LjGDzBD4fipATjFZGn8GKN
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    parsec-3.1.16.1 template-haskell-2.19.0.0 text-2.0.2
    th-lift-instances-0.1.20-AeUdbWqQ7Hq4NSZBSNUP4Q

haddock-interfaces:
    /usr/share/doc/haskell-unicode-collation/html/unicode-collation.haddock

haddock-html:         /usr/share/doc/haskell-unicode-collation/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
